==> firebase_repository-1.0.8.tar.gz: lib/src/models/empresa.dart <==
import 'package:meta/meta.dart';

import '../entities/entities.dart';

@immutable
class Empresa {
  final String uuid;
  final bool activo;
  final String adminNombre;
  final String adminApellido;
  final String email;
  final DateTime fechaAlta;
  final DateTime fechaVto;
  final String empNombre;
  final String telefono;
  final bool caravanas;
  final bool potreros;
  final bool feedlot;
  final String cuig;

  Empresa(
      {this.uuid,
      this.activo,
      this.adminNombre,
      this.adminApellido,
      this.email,
      this.fechaAlta,
      this.fechaVto,
      this.empNombre,
      this.telefono,
      this.caravanas,
      this.potreros,
      this.feedlot,
      this.cuig});

  @override
  String toString() {
    return 'Empresa{uuid: $uuid, activo: $activo, adminNombre: $adminNombre, adminApellido: $adminApellido, email: $email, fechaAlta: $fechaAlta, fechaVto: $fechaVto, empNombre: $empNombre, telefono: $telefono, caravanas: $caravanas, potreros: $potreros, feedlot: $feedlot, cuig: $cuig}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is Empresa &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          activo == other.activo &&
          adminNombre == other.adminNombre &&
          adminApellido == other.adminApellido &&
          email == other.email &&
          fechaAlta == other.fechaAlta &&
          fechaVto == other.fechaVto &&
          empNombre == other.empNombre &&
          telefono == other.telefono &&
          caravanas == other.caravanas &&
          potreros == other.potreros &&
          feedlot == other.feedlot &&
          cuig == other.cuig;

  @override
  int get hashCode =>
      uuid.hashCode ^
      activo.hashCode ^
      adminNombre.hashCode ^
      adminApellido.hashCode ^
      email.hashCode ^
      fechaAlta.hashCode ^
      fechaVto.hashCode ^
      empNombre.hashCode ^
      telefono.hashCode ^
      caravanas.hashCode ^
      potreros.hashCode ^
      feedlot.hashCode ^
      cuig.hashCode;

  Empresa copyWith(
      {String uuid,
      bool activo,
      String adminNombre,
      String adminApellido,
      String email,
      DateTime fechaAlta,
      DateTime fechaVto,
      String empNombre,
      String telefono,
      bool caravanas,
      bool potreros,
      bool feedlot,
      String cuig}) {
    return Empresa(
        activo: activo ?? this.activo,
        adminNombre: adminNombre ?? this.adminNombre,
        adminApellido: adminApellido ?? this.adminApellido,
        email: email ?? this.email,
        fechaAlta: fechaAlta ?? this.fechaAlta,
        fechaVto: fechaVto ?? this.fechaVto,
        empNombre: empNombre ?? this.empNombre,
        telefono: telefono ?? this.telefono,
        caravanas: caravanas ?? this.caravanas,
        potreros: potreros ?? this.potreros,
        feedlot: feedlot ?? this.feedlot,
        cuig: cuig ?? this.cuig);
  }

  EmpresaEntity toEntity() {
    return EmpresaEntity(
        uuid,
        activo,
        adminNombre,
        adminApellido,
        email,
        fechaAlta,
        fechaVto,
        empNombre,
        telefono,
        caravanas,
        potreros,
        feedlot,
        cuig);
  }

  static Empresa fromEntity(EmpresaEntity entity){
    return Empresa(
      uuid: entity.uuid,
      activo: entity.activo,
      adminNombre: entity.adminNombre,
      adminApellido: entity.adminApellido,
      email: entity.email,
      fechaAlta: entity.fechaAlta,
      fechaVto: entity.fechaVto,
      empNombre: entity.empNombre,
      telefono: entity.telefono,
      caravanas: entity.caravanas,
      potreros: entity.potreros,
      feedlot: entity.feedlot,
      cuig: entity.cuig
    );
  }
}

==> firebase_repository-1.0.34.tar.gz: lib/src/models/empresa.dart <==
import 'package:meta/meta.dart';

import '../entities/entities.dart';

@immutable
class Empresa {
  final String uuid;
  final bool activo;
  final String adminNombre;
  final String adminApellido;
  final String email;
  final DateTime fechaAlta;
  final DateTime fechaVto;
  final String empNombre;
  final String telefono;
  final bool caravanas;
  final bool potreros;
  final bool feedlot;
  final String cuig;
  final int tolerancia;
  final int toleranciaRemanente;

  Empresa(
      {this.uuid,
      this.activo,
      this.adminNombre,
      this.adminApellido,
      this.email,
      this.fechaAlta,
      this.fechaVto,
      this.empNombre,
      this.telefono,
      this.caravanas,
      this.potreros,
      this.feedlot,
      this.cuig,
      this.tolerancia,
      this.toleranciaRemanente});

  @override
  String toString() {
    return 'Empresa{uuid: $uuid, activo: $activo, adminNombre: $adminNombre, adminApellido: $adminApellido, email: $email, fechaAlta: $fechaAlta, fechaVto: $fechaVto, empNombre: $empNombre, telefono: $telefono, caravanas: $caravanas, potreros: $potreros, feedlot: $feedlot, cuig: $cuig, tolerancia: $tolerancia, toleranciaRemanente: $toleranciaRemanente}';
  }

  @override
  bool operator ==(Object other) =>
      identical(this, other) ||
      other is Empresa &&
          runtimeType == other.runtimeType &&
          uuid == other.uuid &&
          activo == other.activo &&
          adminNombre == other.adminNombre &&
          adminApellido == other.adminApellido &&
          email == other.email &&
          fechaAlta == other.fechaAlta &&
          fechaVto == other.fechaVto &&
          empNombre == other.empNombre &&
          telefono == other.telefono &&
          caravanas == other.caravanas &&
          potreros == other.potreros &&
          feedlot == other.feedlot &&
          cuig == other.cuig &&
          tolerancia == other.tolerancia &&
          toleranciaRemanente == other.toleranciaRemanente;

  @override
  int get hashCode =>
      uuid.hashCode ^
      activo.hashCode ^
      adminNombre.hashCode ^
      adminApellido.hashCode ^
      email.hashCode ^
      fechaAlta.hashCode ^
      fechaVto.hashCode ^
      empNombre.hashCode ^
      telefono.hashCode ^
      caravanas.hashCode ^
      potreros.hashCode ^
      feedlot.hashCode ^
      cuig.hashCode ^
      tolerancia.hashCode ^
      toleranciaRemanente.hashCode;

  Empresa copyWith(
      {String uuid,
      bool activo,
      String adminNombre,
      String adminApellido,
      String email,
      DateTime fechaAlta,
      DateTime fechaVto,
      String empNombre,
      String telefono,
      bool caravanas,
      bool potreros,
      bool feedlot,
      String cuig,
      int tolerancia,
      int toleranciaRemanente}) {
    return Empresa(
        activo: activo ?? this.activo,
        adminNombre: adminNombre ?? this.adminNombre,
        adminApellido: adminApellido ?? this.adminApellido,
        email: email ?? this.email,
        fechaAlta: fechaAlta ?? this.fechaAlta,
        fechaVto: fechaVto ?? this.fechaVto,
        empNombre: empNombre ?? this.empNombre,
        telefono: telefono ?? this.telefono,
        caravanas: caravanas ?? this.caravanas,
        potreros: potreros ?? this.potreros,
        feedlot: feedlot ?? this.feedlot,
        cuig: cuig ?? this.cuig,
        tolerancia: tolerancia ?? this.tolerancia,
        toleranciaRemanente: toleranciaRemanente ?? this.toleranciaRemanente);
  }

  EmpresaEntity toEntity() {
    return EmpresaEntity(
        uuid,
        activo,
        adminNombre,
        adminApellido,
        email,
        fechaAlta,
        fechaVto,
        empNombre,
        telefono,
        caravanas,
        potreros,
        feedlot,
        cuig,
        tolerancia,
        toleranciaRemanente
    );
  }

  static Empresa fromEntity(EmpresaEntity entity) {
    return Empresa(
        uuid: entity.uuid,
        activo: entity.activo,
        adminNombre: entity.adminNombre,
        adminApellido: entity.adminApellido,
        email: entity.email,
        fechaAlta: entity.fechaAlta,
        fechaVto: entity.fechaVto,
        empNombre: entity.empNombre,
        telefono: entity.telefono,
        caravanas: entity.caravanas,
        potreros: entity.potreros,
        feedlot: entity.feedlot,
        cuig: entity.cuig,
        tolerancia: entity.tolerancia,
        toleranciaRemanente: entity.toleranciaRemanente
    );
  }
}
